"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const node_osc_1 = require("node-osc");
const youtube_1 = require("./youtube");
const niconico_1 = require("./niconico");
const endpoint = "127.0.0.1";
const port = 19100;
const defaultPostApi = "/vc-official/onecomme/common";
class MessageConverter {
    convert(comment) {
        let service = comment.service;
        let data = comment.data;
        if (service == "youtube" && this.isYouTubeComment(data)) {
            return data.hasGift
                ? new youtube_1.YouTubeSuperChat(data)
                : new youtube_1.YouTubeComment(data);
        }
        if (service == "niconama" && this.isNiconamaComment(data)) {
            return data.hasGift
                ? new niconico_1.NiconamaGift(data)
                : new niconico_1.NiconamaComment(data);
        }
        return undefined;
    }
    isYouTubeComment(subject) {
        return subject !== undefined;
    }
    isNiconamaComment(subject) {
        return subject !== undefined;
    }
}
class Domain {
    constructor() {
        this.uid = "onecomme-osc";
        this.name = "VirtualCast公式わんコメOSCプラグイン";
        this.version = "1.2.0";
        this.author = "Virtual Cast, Inc.";
        this.url = "https://wiki.virtualcast.jp/wiki/deliverytool/onecomme/plugin";
        this.permissions = [
            "comments",
        ];
        this.defaultState = {};
        // Custom
        this.converter = new MessageConverter();
        this.client = null;
    }
    init(_api, _initialData) {
        console.info("onecomme-osc initializing.");
        this.client = new node_osc_1.Client(endpoint, port);
    }
    destroy() {
        var _a;
        console.info("onecomme-osc disposing.");
        (_a = this.client) === null || _a === void 0 ? void 0 : _a.close();
        this.client = null;
    }
    subscribe(type, ...args) {
        console.info(`onecomme-osc subscription notified. Type of ${type}`);
        if (type != "comments")
            return;
        args.forEach(x => {
            if (!x.comments)
                return;
            this.processComments(x.comments);
        });
    }
    processComments(comments) {
        comments.forEach((cm) => {
            const subject = this.converter.convert(cm);
            if (subject === undefined)
                return;
            const json = subject.getJson();
            const jsonUtf8 = Buffer.from(json, "utf-8");
            this.send(subject.endpoint, jsonUtf8);
            const post = subject.asPost();
            if (post === undefined)
                return;
            const postJson = JSON.stringify(post);
            const postUtf8 = Buffer.from(postJson, "utf-8");
            this.send(defaultPostApi, postUtf8);
        });
    }
    send(oscEndpoint, data) {
        var _a;
        console.info(`send message; ${data}; destination: ${oscEndpoint}`);
        const message = new node_osc_1.Message(oscEndpoint, data);
        (_a = this.client) === null || _a === void 0 ? void 0 : _a.send(message);
    }
}
module.exports = new Domain();
