"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.YouTubeSuperChat = exports.YouTubeComment = void 0;
const types_1 = require("./types");
const comment_1 = require("./comment");
const youtubeCommentApi = "/vc-official/onecomme/youtube/comment";
const youtubeSuperApi = "/vc-official/onecomme/youtube/super";
class YouTubeCommon {
    constructor(raw) {
        this.id = raw.id;
        this.liveId = raw.liveId;
        this.userId = raw.userId;
        this.name = raw.name;
        this.isOwner = raw.isOwner;
        this.isModerator = raw.isModerator;
        this.isMember = raw.isMember;
        this.autoModerated = raw.autoModerated;
        this.timestamp = types_1.Timestamp.from(raw.timestamp);
        this.hasGift = raw.hasGift;
        this.comment = (0, comment_1.normalizeEmoji)(raw.comment);
        this.displayName = raw.displayName;
        this.profileImageUrl = (0, comment_1.resizeYoutubeProfileImageUrl)(raw.profileImage);
    }
    asPost() {
        return {
            type: this.type,
            author: this.name,
            comment: this.comment,
            timestamp: this.timestamp,
            iconUrl: this.profileImageUrl
        };
    }
}
class YouTubeComment extends YouTubeCommon {
    constructor(raw) {
        super(raw);
        this.type = "youtube";
        this.endpoint = youtubeCommentApi;
    }
    getJson() {
        return JSON.stringify(this);
    }
}
exports.YouTubeComment = YouTubeComment;
class YouTubeSuperChat extends YouTubeCommon {
    constructor(raw) {
        super(raw);
        this.type = "youtube-super";
        this.endpoint = youtubeSuperApi;
        this.paidText = raw.paidText;
        this.price = raw.price;
        this.unit = raw.unit;
        this.colors = this.convert(raw.colors);
        this.tier = raw.tier;
    }
    asPost() {
        const base = super.asPost();
        if (!base
            || !this.paidText
            || !this.price
            || !this.unit
            || !this.colors
            || !this.tier) {
            return undefined;
        }
        const obj = Object.assign(Object.assign({}, base), { paidText: this.paidText, price: this.price, tier: this.tier, unit: this.unit, colors: this.colors });
        return obj;
    }
    getJson() {
        return JSON.stringify(this);
    }
    convert(colors) {
        if (!colors)
            return undefined;
        return {
            headerBackgroundColor: types_1.Color.from(colors.headerBackgroundColor),
            headerTextColor: types_1.Color.from(colors.headerTextColor),
            bodyBackgroundColor: types_1.Color.from(colors.bodyBackgroundColor),
            bodyTextColor: types_1.Color.from(colors.bodyTextColor),
            authorNameTextColor: (0, types_1.bind)(colors.authorNameTextColor, types_1.Color.from),
            timestampColor: (0, types_1.bind)(colors.timestampColor, types_1.Color.from)
        };
    }
}
exports.YouTubeSuperChat = YouTubeSuperChat;
